@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "apheleia" "4.4.3"
+(define-package "apheleia" "20251111.1140"
   "Reformat buffer stably."
   '((emacs "27"))
   :url "https://github.com/radian-software/apheleia"
-  :commit "2bc2bb4cc2caad111e6f2f1b9daf20ec388101ff"
-  :revdesc "2bc2bb4cc2ca"
+  :commit "e7892adc8a23612b219513ea56f62cdb825afe8f"
+  :revdesc "e7892adc8a23"
   :keywords '("tools")
   :authors '(("Radian LLC" . "contact+apheleia@radian.codes"))
   :maintainers '(("Radian LLC" . "contact+apheleia@radian.codes")))
